@@ -30,14 +30,15 @@ IEX_TOKEN: str = 'Tpk_a4bc3e95d4c94810a3b2d4138dc81c5d'
 os.environ['IEX_API_VERSION'] = 'iexcloud-sandbox'
 os.environ['IEX_TOKEN'] = IEX_TOKEN
 __author__: str = 'Vlad Kochetov'
-__credits__: List[str] = ["Hemerson Tacon  -- Stack overflow",
-                          "hpaulj          -- Stack overflow",
-                          "furas           -- Stack overflow",
+__credits__: List[str] = ["Hemerson Tacon -- Stack overflow",
+                          "hpaulj -- Stack overflow",
+                          "furas -- Stack overflow",
                           "Войтенко Николай Поликарпович (Vojtenko Nikolaj Polikarpovich) -- helped me test the "
                           "system of interaction with the binance crypto exchange with 50 dollars.",
                           "https://fxgears.com/index.php?threads/how-to-acquire-free-historical-tick-and-bar-data-for"
-                          "-algo-trading-and-backtesting-in-2020-stocks-forex-and-crypto-currency.1229/#post-19305"]
-__version__: str = "3.8.5"
+                          "-algo-trading-and-backtesting-in-2020-stocks-forex-and-crypto-currency.1229/#post-19305"
+                          " -- binance get historical data method"]
+__version__: str = "3.9.5"
 
 BASE_TICKER: str = '^DJI'
 SCATTER_SIZE: float = 12.0
@@ -218,12 +219,13 @@ def get_IEX_minutely(ticker: str, undo_days: int) -> pd.DataFrame:
     return returns.dropna()
 
 
-def anti_set_(seted: List[Any]) -> List[Any]:
+def anti_set_(seted: List[Any], _nan_num: float = 18699.9) -> List[Any]:
+    seted = np.nan_to_num(seted, nan=_nan_num)
     ret: List[Any] = [seted[0]]
     flag = seted[0]
     e: int
-    for e, i in enumerate(seted[1:]):
-        if i is np.nan:
+    for i in seted[1:]:
+        if i == _nan_num:
             ret.append(flag)
         else:
             ret.append(i)
@@ -280,3 +282,14 @@ def convert_signal_str(predict: PREDICT_TYPE) -> str:
         return 'Sell'
     elif predict == EXIT:
         return 'Exit'
+
+def ta_lib_to_returns(talib_returns: pd.Series, exit_=EXIT, *args, **kwargs) -> PREDICT_TYPE_LIST:
+    return list(talib_returns.replace({-200: SELL,
+                                       200: BUY,
+                                       100: BUY,
+                                       -100: SELL,
+                                       0: exit_}).values)
+
+
+def ta_lib_collider_all(data, *args, **kwargs):
+    return ta_lib_to_returns(data, exit_=np.nan)
